@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: Stereochemistry handling routines
-our $VERSION = '0.8.4'; # VERSION
+our $VERSION = '0.8.6'; # VERSION
 
 require Exporter;
 our @ISA = qw( Exporter );
@@ -25,11 +25,11 @@ use Chemistry::OpenSMILES qw(
 use Chemistry::OpenSMILES::Writer qw( write_SMILES );
 use Graph::Traversal::BFS;
 use Graph::Undirected;
-use List::Util qw( all any max min sum sum0 );
+use List::Util qw( all any max min sum sum0 uniq );
 
 sub mark_all_double_bonds
 {
-    my( $graph, $setting_sub, $order_sub ) = @_;
+    my( $graph, $setting_sub, $order_sub, $color_sub ) = @_;
 
     # By default, whenever there is a choice between atoms, the one with
     # lowest position in the input SMILES is chosen:
@@ -38,7 +38,7 @@ sub mark_all_double_bonds
     # Select non-ring double bonds
     my @double_bonds = grep { is_double_bond( $graph, @$_ ) &&
                               !is_ring_bond( $graph, @$_ ) &&
-                              !is_unimportant_double_bond( $graph, @$_ ) }
+                              !is_unimportant_double_bond( $graph, @$_, $color_sub ) }
                             $graph->edges;
 
     # Construct a double bond incidence graph. Vertices are double bonds
@@ -342,24 +342,26 @@ sub is_pseudoedge
     return $moiety->has_edge_attribute( $a, $b, 'pseudo' );
 }
 
-# An "unimportant" double bond is one which has leaf atoms on one of its
-# sides and both of these atoms are identical.
+# An "unimportant" double bond is one which has chemically identical atoms on one of its sides.
+# If C<$color_sub> is given, it is used to determine chemical identity of atoms.
+# If not, only leaf atoms are considered and compared.
 sub is_unimportant_double_bond
 {
-    my( $moiety, $a, $b ) = @_;
+    my( $moiety, $a, $b, $color_sub ) = @_;
     my @a_neighbours = grep { $_ != $b } $moiety->neighbours( $a );
     my @b_neighbours = grep { $_ != $a } $moiety->neighbours( $b );
 
-    if( @a_neighbours == 2 &&
-        all { $moiety->degree( $_ ) == 1 } @a_neighbours ) {
-        return 1 if write_SMILES( $a_neighbours[0] ) eq
-                    write_SMILES( $a_neighbours[1] );
-    }
+    for (\@a_neighbours, \@b_neighbours) {
+        next unless @$_ == 2;
 
-    if( @b_neighbours == 2 &&
-        all { $moiety->degree( $_ ) == 1 } @b_neighbours ) {
-        return 1 if write_SMILES( $b_neighbours[0] ) eq
-                    write_SMILES( $b_neighbours[1] );
+        my @representations;
+        if( $color_sub ) {
+            @representations = map { $color_sub->( $_ ) } @$_;
+        } else {
+            next if any { $moiety->degree( $_ ) != 1 } @$_;
+            @representations = map { write_SMILES( $_ ) } @$_;
+        }
+        return 1 if uniq( @representations ) == 1;
     }
 
     return;
